@@ -4,7 +4,7 @@ Main interface for codedeploy service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_codedeploy import (
         Client,
         CodeDeployClient,
@@ -20,10 +20,8 @@ Usage::
         ListOnPremisesInstancesPaginator,
     )
 
-    session = boto3.Session()
-
-    client: CodeDeployClient = boto3.client("codedeploy")
-    session_client: CodeDeployClient = session.client("codedeploy")
+    session = Session()
+    client: CodeDeployClient = session.client("codedeploy")
 
     deployment_successful_waiter: DeploymentSuccessfulWaiter = client.get_waiter("deployment_successful")
 
