@@ -37,8 +37,7 @@ Usage::
 """
 from typing import Generic, Iterator, Mapping, Sequence, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .literals import (
     ApplicationRevisionSortByType,
@@ -88,7 +87,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListApplicationRevisionsPaginator(Boto3Paginator):
+class ListApplicationRevisionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplicationRevisions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators/#listapplicationrevisionspaginator)
@@ -111,7 +110,7 @@ class ListApplicationRevisionsPaginator(Boto3Paginator):
         """
 
 
-class ListApplicationsPaginator(Boto3Paginator):
+class ListApplicationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codedeploy.html#CodeDeploy.Paginator.ListApplications)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators/#listapplicationspaginator)
@@ -126,7 +125,7 @@ class ListApplicationsPaginator(Boto3Paginator):
         """
 
 
-class ListDeploymentConfigsPaginator(Boto3Paginator):
+class ListDeploymentConfigsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentConfigs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators/#listdeploymentconfigspaginator)
@@ -141,7 +140,7 @@ class ListDeploymentConfigsPaginator(Boto3Paginator):
         """
 
 
-class ListDeploymentGroupsPaginator(Boto3Paginator):
+class ListDeploymentGroupsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentGroups)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators/#listdeploymentgroupspaginator)
@@ -156,7 +155,7 @@ class ListDeploymentGroupsPaginator(Boto3Paginator):
         """
 
 
-class ListDeploymentInstancesPaginator(Boto3Paginator):
+class ListDeploymentInstancesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentInstances)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators/#listdeploymentinstancespaginator)
@@ -176,7 +175,7 @@ class ListDeploymentInstancesPaginator(Boto3Paginator):
         """
 
 
-class ListDeploymentTargetsPaginator(Boto3Paginator):
+class ListDeploymentTargetsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeploymentTargets)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators/#listdeploymenttargetspaginator)
@@ -195,7 +194,7 @@ class ListDeploymentTargetsPaginator(Boto3Paginator):
         """
 
 
-class ListDeploymentsPaginator(Boto3Paginator):
+class ListDeploymentsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codedeploy.html#CodeDeploy.Paginator.ListDeployments)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators/#listdeploymentspaginator)
@@ -217,7 +216,7 @@ class ListDeploymentsPaginator(Boto3Paginator):
         """
 
 
-class ListGitHubAccountTokenNamesPaginator(Boto3Paginator):
+class ListGitHubAccountTokenNamesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codedeploy.html#CodeDeploy.Paginator.ListGitHubAccountTokenNames)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators/#listgithubaccounttokennamespaginator)
@@ -232,7 +231,7 @@ class ListGitHubAccountTokenNamesPaginator(Boto3Paginator):
         """
 
 
-class ListOnPremisesInstancesPaginator(Boto3Paginator):
+class ListOnPremisesInstancesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codedeploy.html#CodeDeploy.Paginator.ListOnPremisesInstances)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/paginators/#listonpremisesinstancespaginator)
