@@ -19,14 +19,14 @@ Usage::
     deployment_successful_waiter: DeploymentSuccessfulWaiter = client.get_waiter("deployment_successful")
     ```
 """
-from botocore.waiter import Waiter as Boto3Waiter
+from botocore.waiter import Waiter
 
 from .type_defs import WaiterConfigTypeDef
 
 __all__ = ("DeploymentSuccessfulWaiter",)
 
 
-class DeploymentSuccessfulWaiter(Boto3Waiter):
+class DeploymentSuccessfulWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codedeploy.html#CodeDeploy.Waiter.DeploymentSuccessful)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codedeploy/waiters/#deploymentsuccessfulwaiter)
